Pseudo-Element | Description
--- | ---
add-line | To-Do
add-page | To-Do
chunk | To-Do
close-button | To-Do
corner | To-Do
down-arrow | To-Do
down-button | To-Do
drop-down | To-Do
float-button | To-Do
groove | To-Do
indicator | To-Do
handle | To-Do
icon | To-Do
item | To-Do
left-arrow | To-Do
left-corner | To-Do
menu-arrow | To-Do
menu-button | To-Do
menu-indicator | To-Do
right-arrow | To-Do
pane | To-Do
right-corner | To-Do
scroller | To-Do
separator | To-Do
sub-line | To-Do
sub-page | To-Do
tab | To-Do
tab-bar | To-Do
tear | To-Do
tearoff | To-Do
title | To-Do
up-arrow | To-Do
up-button | To-Do